@@ -1,3 +1,5 @@
+from fileinput import filename
+import fnmatch
 from typing import Optional
 from dataclasses import dataclass
 from subprocess import run, PIPE
@@ -63,8 +65,16 @@ def get_repo_name() -> str:
     return name
 
 
+def changed_since(start_commit: str, file_pattern: str) -> bool:
+    cmd = ["git", "diff", "--name-only", start_commit, "HEAD"]
+    result = run(cmd, stdout=PIPE)
+    filenames = result.stdout.decode().strip().split("\n")
+    matches = fnmatch.filter(filenames, file_pattern)
+    return len(matches) > 0
+
+
 def _is_ancestor(commit_a: str, commit_b: str) -> bool:
     """Checks if commit_a is an ancestor of commit_b"""
-    cmd = ["git", "merge-head", "--is-ancestor", commit_a, commit_b]
+    cmd = ["git", "merge-base", "--is-ancestor", commit_a, commit_b]
     result = run(cmd, stdout=PIPE)
     return result.returncode == 0
